==> mastercard_spendcontrols-1.0.0-py2-none-any.whl: mastercardspendcontrols/crossborderdecline.py <==
#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


from mastercardapicore import BaseObject
from mastercardapicore import RequestMap
from mastercardapicore import OperationConfig
from mastercardapicore import OperationMetadata
from resourceconfig import ResourceConfig

class Crossborderdecline(BaseObject):
	"""
	
	"""

	__config = {
		
		"04b37632-6229-464e-b7de-a250b56bc05c" : OperationConfig("/issuer/v1/card/{uuid}/controls/declines/crossborder", "delete", [], []),
		
		"9169023f-54ab-44a8-a260-83732608e4c4" : OperationConfig("/issuer/v1/card/{uuid}/controls/declines/crossborder", "query", [], []),
		
		"58abdfd7-daa8-400b-af41-d3904aa3fba5" : OperationConfig("/issuer/v1/card/{uuid}/controls/declines/crossborder", "create", [], []),
		
	}

	def getOperationConfig(self,operationUUID):
		if operationUUID not in self.__config:
			raise Exception("Invalid operationUUID: "+operationUUI)

		return self.__config[operationUUID]

	def getOperationMetadata(self):
		return OperationMetadata(ResourceConfig.getInstance().getVersion(), ResourceConfig.getInstance().getHost(), ResourceConfig.getInstance().getContext())





	@classmethod
	def deleteById(cls,id,map=None):
		"""
		Delete object of type Crossborderdecline by id

		@param str id
		@return Crossborderdecline of the response of the deleted instance.
		@raise ApiException: raised an exception from the response status
		"""

		mapObj =  RequestMap()
		if id:
			mapObj.set("id", id)

		if map:
			if (isinstance(map,RequestMap)):
				mapObj.setAll(map.getObject())
			else:
				mapObj.setAll(map)

		return BaseObject.execute("04b37632-6229-464e-b7de-a250b56bc05c", Crossborderdecline(mapObj))

	def delete(self):
		"""
		Delete object of type Crossborderdecline

		@return Crossborderdecline of the response of the deleted instance.
		@raise ApiException: raised an exception from the response status
		"""
		return BaseObject.execute("04b37632-6229-464e-b7de-a250b56bc05c", self)








	@classmethod
	def query(cls,criteria):
		"""
		Query objects of type Crossborderdecline by id and optional criteria
		@param type criteria
		@return Crossborderdecline object representing the response.
		@raise ApiException: raised an exception from the response status
		"""

		return BaseObject.execute("9169023f-54ab-44a8-a260-83732608e4c4", Crossborderdecline(criteria))

	@classmethod
	def create(cls,mapObj):
		"""
		Creates object of type Crossborderdecline

		@param Dict mapObj, containing the required parameters to create a new object
		@return Crossborderdecline of the response of created instance.
		@raise ApiException: raised an exception from the response status
		"""
		return BaseObject.execute("58abdfd7-daa8-400b-af41-d3904aa3fba5", Crossborderdecline(mapObj))

==> mastercard_spendcontrols-1.0.3-py2-none-any.whl: mastercardspendcontrols/crossborderdecline.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


from mastercardapicore import BaseObject
from mastercardapicore import RequestMap
from mastercardapicore import OperationConfig
from mastercardapicore import OperationMetadata
from resourceconfig import ResourceConfig

class Crossborderdecline(BaseObject):
	"""
	
	"""

	__config = {
		
		"9e4fff3b-03da-4eb6-b6df-83d62349ba80" : OperationConfig("/issuer/spendcontrols/v1/card/{uuid}/controls/declines/crossborder", "delete", [], []),
		
		"a0bf2fbd-62e1-4df4-8929-eec7c0739923" : OperationConfig("/issuer/spendcontrols/v1/card/{uuid}/controls/declines/crossborder", "query", [], []),
		
		"d2769822-522b-4648-915b-38959f993226" : OperationConfig("/issuer/spendcontrols/v1/card/{uuid}/controls/declines/crossborder", "create", [], []),
		
	}

	def getOperationConfig(self,operationUUID):
		if operationUUID not in self.__config:
			raise Exception("Invalid operationUUID: "+operationUUID)

		return self.__config[operationUUID]

	def getOperationMetadata(self):
		return OperationMetadata(ResourceConfig.getInstance().getVersion(), ResourceConfig.getInstance().getHost(), ResourceConfig.getInstance().getContext(), ResourceConfig.getInstance().getJsonNative())





	@classmethod
	def deleteById(cls,id,map=None):
		"""
		Delete object of type Crossborderdecline by id

		@param str id
		@return Crossborderdecline of the response of the deleted instance.
		@raise ApiException: raised an exception from the response status
		"""

		mapObj =  RequestMap()
		if id:
			mapObj.set("id", id)

		if map:
			if (isinstance(map,RequestMap)):
				mapObj.setAll(map.getObject())
			else:
				mapObj.setAll(map)

		return BaseObject.execute("9e4fff3b-03da-4eb6-b6df-83d62349ba80", Crossborderdecline(mapObj))

	def delete(self):
		"""
		Delete object of type Crossborderdecline

		@return Crossborderdecline of the response of the deleted instance.
		@raise ApiException: raised an exception from the response status
		"""
		return BaseObject.execute("9e4fff3b-03da-4eb6-b6df-83d62349ba80", self)








	@classmethod
	def query(cls,criteria):
		"""
		Query objects of type Crossborderdecline by id and optional criteria
		@param type criteria
		@return Crossborderdecline object representing the response.
		@raise ApiException: raised an exception from the response status
		"""

		return BaseObject.execute("a0bf2fbd-62e1-4df4-8929-eec7c0739923", Crossborderdecline(criteria))

	@classmethod
	def create(cls,mapObj):
		"""
		Creates object of type Crossborderdecline

		@param Dict mapObj, containing the required parameters to create a new object
		@return Crossborderdecline of the response of created instance.
		@raise ApiException: raised an exception from the response status
		"""
		return BaseObject.execute("d2769822-522b-4648-915b-38959f993226", Crossborderdecline(mapObj))
